@@ -19,7 +19,7 @@
 
 package FindBin::libs;
 
-use v5.14;
+use v5.10;
 use strict;
 
 use FindBin;
@@ -27,9 +27,8 @@ use Symbol;
 
 use File::Basename;
 
-use Carp        qw( croak           );
-use List::Util  qw( first           );
-use Symbol      qw( qualify_to_ref  );
+use Carp    qw( croak           );
+use Symbol  qw( qualify_to_ref  );
 
 use File::Spec::Functions
 qw
@@ -54,42 +53,35 @@ BEGIN
     # cannot handle the rooted system being linked
     # back to itself.
 
-    use Cwd qw( &cwd );
+    use Cwd qw( &abs_path &cwd );
 
-    my $abs = Cwd->can( 'abs_path'  )
-    or die "Odd: Cwd cannot 'abs_path'\n";
-
-    if
-    (
-        eval { $abs->( '//' );  $abs->( cwd ); 1 }
-    )
+    unless( eval {abs_path '//';  abs_path cwd } )
     {
-        # nothing more to do: abs_path works.
-    }
-    elsif
-    (
-        $abs = File::Spec::Functions->can( 'rel2abs'  )
-    )
-    {
-        # ok, we have a substitute
-    }
-    else
-    {
-        die "Non-working abs_path without 'rel2abs'\n";
-    }
+        # abs_path seems to be having problems,
+        # fix is to stub it out.
+        #
+        # undef avoids nastygram.
 
-    my $ref = *{ qualify_to_ref 'abs_path', __PACKAGE__ };
+        my $ref = qualify_to_ref 'abs_path', __PACKAGE__;
 
-    undef &{ *$ref };
+        my $sub = File::Spec::Functions->can( 'rel2abs' );
 
-    *{ $ref } = $abs;
+        undef &{ $ref };
+
+        *$ref = $sub
+    };
 }
 
 ########################################################################
 # package variables 
 ########################################################################
 
-our $VERSION = v2.0.0;
+our $VERSION
+= do
+{
+    my $v   = '2.01';
+    eval $v
+};
 
 my %defaultz = 
 (
@@ -110,8 +102,6 @@ my %defaultz =
     ignore => '/,/usr', # dir's to skip looking for ./lib
 );
 
-my @use_undef = qw( export ignore );
-
 # only new directories are used, ignore pre-loads
 # this with unwanted values.
 
@@ -170,6 +160,7 @@ my $find_libs
 
     my @libz    = ();
 
+    PATH:
     for( 1 .. @dirpath )
     {
         # note that catpath is extraneous on *NIX; the 
@@ -204,6 +195,8 @@ my $find_libs
                 $found{ $dir } = ();
 
                 push @libz, $dir;
+
+                last if $argz{ scalar };
             }
         }
 
@@ -235,18 +228,25 @@ my $handle_args
     %argz
     = map
     {
+        my $use_undef
+        = do
+        {
+            my %a   = ();
+            @a{ qw( export ignore ) } = ();
+            \%a
+        };
+
         my ( $k, $v ) = split '=', $_, 2;
 
-        defined $v
-        or 
-        first { $_ eq $k } @use_undef 
-        or 
-        $v  //= 1;
+        # leave $v undef?
+
+        exists $use_undef->{ $k }
+        or $v //= 1;
 
         # "no" inverts the sense of the test.
 
-        index $k, 'no'
-        or $v  = ! $v;
+        $k =~ s{^no}{}
+        and $v  = ! $v;
 
         ( $k => $v )
     }
@@ -287,12 +287,12 @@ my $handle_args
 
     while( my($k,$v) = each %defaultz )
     {
-    # //= doesn't work here since undef may be a 
-    # legit default.
+        # //= doesn't work here since undef may be a 
+        # legit default.
 
-    exists $argz{ $k }
-    or
-    $argz{ $k } = $v;
+        exists $argz{ $k }
+        or
+        $argz{ $k } = $v;
     }
 
     exists $argz{ base } && $argz{ base } 
@@ -343,7 +343,7 @@ sub import
     # of inside find_libs allows people to use saner
     # untainting plans via find_libs.
 
-    @libz   = map { m{ (.+) }x } @libz;
+    @libz   = map { m{ (.+) }xs } @libz;
 
     my $caller = caller;
 
@@ -358,16 +358,22 @@ sub import
 
     if( $argz{ export } )
     {
-        my $dest    = qualify        $argz{ export }, $caller;
-        my $ref     = qualify_to_ref $dest;
+        my $ref     = qualify_to_ref $argz{ export }, $caller;
 
-        print STDERR "\nExporting: \@$dest\n"
-        if $verbose;
+        if( $verbose )
+        {
+            my $dest    = qualify $argz{ export }, $caller;
 
-        # Symbol this is cleaner than "no strict" 
-        # for installing the array.
+            $argz{ scalar }
+            ? print STDERR "\nExporting: \$$dest\n"
+            : print STDERR "\nExporting: \@$dest\n"
+            ;
+        }
 
-        *$ref = \@libz;
+        $argz{ scalar }
+        ? *$ref = \$libz[0]
+        : *$ref = \@libz;
+        ;
     }
 
     if( defined $argz{ p5lib } )
@@ -592,7 +598,7 @@ for configuring packages:
 
     use FindBin::libs qw( export base=config subonly=mypackage );
 
-Will leave @config with any "mypackage" holding
+Will leave @config with any "mypacakge" holding
 any "mypackage" subdir's.
 
 =head3 Setting PERL5LIB: p5lib
@@ -673,7 +679,7 @@ having to modify a single line of code.
 Say your sandbox is in ./sandbox and you are currently
 working in ./sandbox/projects/package/bin on a perl
 executable. You may have some number of modules that
-are specific -- or customized -- for this package, 
+are specific -- or customized -- for this pacakge, 
 share some modules within the project, and may want 
 to use company-wide modules that are managed out of 
 ./sandbox in development. All of this lives under a 
